<?php
$TRANSLATIONS = array(
"Authentication error" => "Ralat pengesahan",
"Email saved" => "Emel disimpan",
"Invalid email" => "Emel tidak sah",
"Language changed" => "Bahasa diubah",
"Invalid request" => "Permintaan tidak sah",
"Disable" => "Nyahaktif",
"Enable" => "Aktif",
"Error" => "Ralat",
"Update" => "Kemaskini",
"Groups" => "Kumpulan",
"Delete" => "Padam",
"never" => "jangan",
"__language_name__" => "_nama_bahasa_",
"Login" => "Log masuk",
"Security Warning" => "Amaran keselamatan",
"Server address" => "Alamat pelayan",
"Log" => "Log",
"Log level" => "Tahap Log",
"More" => "Lanjutan",
"Add your App" => "Tambah apps anda",
"Select an App" => "Pilih aplikasi",
"See application page at apps.owncloud.com" => "Lihat halaman applikasi di apps.owncloud.com",
"Password" => "Kata laluan",
"Unable to change your password" => "Gagal mengubah kata laluan anda ",
"Current password" => "Kata laluan semasa",
"New password" => "Kata laluan baru",
"Change password" => "Ubah kata laluan",
"Email" => "Email",
"Your email address" => "Alamat emel anda",
"Profile picture" => "Gambar profil",
"Cancel" => "Batal",
"Language" => "Bahasa",
"Help translate" => "Bantu terjemah",
"Login Name" => "Log masuk",
"Create" => "Buat",
"Default Quota" => "Kuota Lalai",
"Other" => "Lain",
"Username" => "Nama pengguna",
"Quota" => "Kuota"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
